@@ -24,7 +24,7 @@ class SyncTransport(Transport):
                  auth_callback=None, otp_token_callback=None,
                  verify_ssl=True, allow_caching=True,
                  cache_location=None, in_memory_cache=False,
-                 save_cookies=True, *args, **kwargs):
+                 save_cookies=True, ext_auth_cookies=None, *args, **kwargs):
         super(SyncTransport, self).__init__(url, *args, **kwargs)
         self.allow_caching = allow_caching
         self.cache_location = cache_location
@@ -40,7 +40,8 @@ class SyncTransport(Transport):
             auth_callback=auth_callback,
             otp_token_callback=otp_token_callback,
             verify_ssl=verify_ssl,
-            save_cookies=save_cookies)
+            save_cookies=save_cookies,
+            ext_auth_cookies=ext_auth_cookies)
 
     def get_root(self):
         return self._execute_request(HttpRequest(self.server.url))
