@@ -56,6 +56,22 @@ class SCMClient(object):
     def check_options(self):
         pass
 
+    def get_changenum(self, revisions):
+        """Return the change number for the given revisions.
+
+        This is only used when the client is supposed to send a change number
+        to the server (such as with Perforce).
+
+        Args:
+            revisions (dict):
+                A revisions dictionary as returned by ``parse_revision_spec``.
+
+        Returns:
+            unicode:
+            The change number to send to the Review Board server.
+        """
+        return None
+
     def scan_for_server(self, repository_info):
         """Find the server path.
 
@@ -376,8 +392,8 @@ def load_scmclients(config, options):
     for ep in pkg_resources.iter_entry_points(group='rbtools_scm_clients'):
         try:
             SCMCLIENTS[ep.name] = ep.load()(config=config, options=options)
-        except Exception as e:
-            logging.error('Could not load SCM Client "%s": %s' % (ep.name, e))
+        except Exception:
+            logging.exception('Could not load SCM Client "%s"', ep.name)
 
 
 def scan_usable_client(config, options, client_name=None):
