@@ -757,11 +757,14 @@ class Post(Command):
                 # normal.
                 pass
 
-        if repository_info.supports_changesets and 'changenum' in diff_info:
+        if (repository_info.supports_changesets and
+            not self.options.diff_filename and
+            'changenum' in diff_info):
             changenum = diff_info['changenum']
-            commit_id = changenum
         else:
-            changenum = None
+            changenum = self.tool.get_changenum(self.revisions)
+
+        commit_id = changenum
 
         if self.options.update and self.revisions:
             review_request = guess_existing_review_request(
